# Duo, A crazy eights game.
# Copyright (C) 2004,2009 The Duo developers.
#
# This file is part of Duo.
#
# Duo is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

"""Duo main module

Duo is a kind of crazy eight or Uno(tm) card game. It is designed to be
modular, so that rule sets, AI or user interfaces can be removed or
added very easily. It is a free software (as in free speech), which is
developed in pure Python and is available in a lot of languages.

Hereafter are the main internal features of Duo, which also represent
the main Python modules.

Artificial Intelligences (AI)
  This pompous term designates the different algorithms Duo can use
  for computer controlled players. The `duo.ai` API allows multiple
  different implementations, but only Camille (`duo.ai.camille`) is
  developed so far.

User Interfaces
  Different environments like heavy 3D systems, text terminals or
  mobile phones can provide different game experiences. Duo user
  interface is interchangeable to take advantage of this. The `duo.ui`
  module provides common interfaces elements.

  The Tk interface (`duo.ui.tk`) is the user interface historically
  developed for the game. Its name comes from the underlying widgets
  framework which is called Tkinter in Python, and relies on Tk. It is
  still today the only supported interface.

Messaging Stack
  Duo relies on a dedicated messaging service which provides
  communication between all the program entities: player interfaces,
  AI, game referee, observer, or whatsoever. This service is composed
  of two layers.

  +-----------------+
  | `duo.protocol`  |
  +-----------------+
  | `duo.transport` |
  +-----------------+

Rules
  The game is controlled by a referee (`duo.referee`) which is the
  only object to know about the game rules. The referee communicates
  with the players (or AI) to notify them the game situation and their
  possible moves. The players, in return, send to the referee all
  their actions.

  The referee relies on a rule set which has its own API (`duo.rules`)
  and can be changes between games.

  This design allows the AI to be stable and to play quite well even
  if the rules came to change.
"""

__docformat__ = 'restructuredtext'
__version__ = '0.10'

import gettext
import locale
import logging


TRANSLATORS = {}


def get_default_language():
    (lang, encoding) = locale.getdefaultlocale()
    return lang

def switch_to_language(lang):
    """Apply the translation for the given language two-letters code."""
    if lang is None:
        return

    try:
        if not TRANSLATORS.has_key(lang):
            TRANSLATORS[lang] = gettext.translation('duo', 'locale', [lang])
    except IOError:
        logging.getLogger('duo').warn(
            'No translation file found for %s' % lang)
    else:
        TRANSLATORS[lang].install(True)
